==> barcode_scanner-1.2.0.tar.gz: lib/barcode_scanning_data.dart <==
import 'dart:typed_data';

import 'package:barcode_scanner/common_data.dart';
import 'package:barcode_scanner/sdk_utils.dart';
import 'package:flutter/cupertino.dart';
import 'package:json_annotation/json_annotation.dart';

import 'barcode_parsers/barcode_scanner.dart';
import 'common_data.dart';

part 'barcode_scanning_data.g.dart';

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class BarcodeScanningResult extends Result {
  List<BarcodeItem> barcodeItems;

  Uri? barcodeImageURI;

  BarcodeScanningResult(List<BarcodeItem>? barcodeItems)
      : barcodeItems = barcodeItems ?? const [];

  BarcodeScanningResult.error(String message) : barcodeItems = const [] {
    operationResult = OperationResult.ERROR;
    this.message = message;
  }

  factory BarcodeScanningResult.fromJson(Map<String, dynamic> json) =>
      _$BarcodeScanningResultFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeScanningResultToJson(this);
}

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class BarcodeItem {
  BarcodeFormattedResult? formattedResult;

  ///Scanned barcode format
  BarcodeFormat barcodeFormat;

  ///Result data from barcode
  String text;

  @JsonKey(fromJson: uintListFromString)

  ///raw data of barcode
  Uint8List? rawBytes;

  BarcodeItem(this.barcodeFormat, this.text);

  factory BarcodeItem.fromJson(Map<String, dynamic> json) =>
      _$BarcodeItemFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeItemToJson(this);
}

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class BarcodeFormattedData {
  String title;
  String subtitle;

  BarcodeFormattedData({required this.title, required this.subtitle});

  factory BarcodeFormattedData.fromJson(Map<String, dynamic> json) =>
      _$BarcodeFormattedDataFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeFormattedDataToJson(this);
}

///Available barcode formats
enum BarcodeFormat {
  AZTEC,
  CODABAR,
  CODE_39,
  CODE_93,
  CODE_128,
  DATA_MATRIX,
  EAN_8,
  EAN_13,
  ITF,
  PDF_417,
  QR_CODE,
  RSS_14,
  RSS_EXPANDED,
  UPC_A,
  UPC_E,
  UNKNOWN
}

class PredefinedBarcodes {
  ///return list of one dimensional barcode formats
  static List<BarcodeFormat> commonBarcodes() {
    return [
      BarcodeFormat.AZTEC,
      BarcodeFormat.CODABAR,
      BarcodeFormat.CODE_39,
      BarcodeFormat.CODE_93,
      BarcodeFormat.CODE_128,
      BarcodeFormat.DATA_MATRIX,
      BarcodeFormat.EAN_8,
      BarcodeFormat.EAN_13,
      BarcodeFormat.ITF,
      BarcodeFormat.PDF_417,
      BarcodeFormat.QR_CODE,
      BarcodeFormat.RSS_14,
      BarcodeFormat.RSS_EXPANDED,
      BarcodeFormat.UPC_A,
      BarcodeFormat.UPC_E
    ];
  }

  ///return list of one dimensional barcode formats
  static List<BarcodeFormat> oneDimensionalBarcodes() {
    return [
      BarcodeFormat.CODE_128,
      BarcodeFormat.CODE_39,
      BarcodeFormat.CODE_93,
      BarcodeFormat.EAN_13,
      BarcodeFormat.EAN_8,
      BarcodeFormat.ITF,
      BarcodeFormat.UPC_E
    ];
  }

  ///return list of two dimensional barcode formats
  static List<BarcodeFormat> twoDimensionalBarcodes() {
    return [
      BarcodeFormat.AZTEC,
      BarcodeFormat.DATA_MATRIX,
      BarcodeFormat.PDF_417,
      BarcodeFormat.QR_CODE
    ];
  }
}

@JsonSerializable(includeIfNull: false, explicitToJson: true)
class BarcodeScannerConfiguration {
  /// Background color of the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarBackgroundColor;

  /// Color of the titles of all buttons in the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsColor;

  /// Background color outside of the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? cameraOverlayColor;

  /// Color of the finder window's outline.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? finderLineColor;

  /// Color of the text hint under the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? finderTextHintColor;

  bool? cancelButtonHidden;

  /// Title of the cancel button.
  String? cancelButtonTitle;

  /// Title of the button that opens the screen where the user can allow
  /// the usage of the camera by the app.
  String? enableCameraButtonTitle;

  /// Text that will be displayed when the app
  /// is not allowed to use the camera, prompting the user
  /// to enable the usage of the camera.
  String? enableCameraExplanationText;

  /// Text hint shown under the finder window.
  String? finderTextHint;

  /// cancel scanning and close view on timeout.
  int? autoCancelTimeout;

  /// Aspect ratio of finder view.
  FinderAspectRatio? finderAspectRatio;

  /// Thickness of the finder window's outline.
  int? finderLineWidth;

  /// Controls whether to play a beep sound after a successful detection.
  /// Default value is TRUE.
  bool? successBeepEnabled;

  /// Controls whether the flash should be initially enabled.
  /// The default value is FALSE.
  bool? flashEnabled;

  /// Orientation lock mode of the camera: PORTRAIT or LANDSCAPE.
  /// By default the camera orientation is not locked.

  CameraOrientationMode? orientationLockMode;

  /// Format of barcode which  need to recognize
  List<BarcodeFormat> barcodeFormats;

  /// Param that handle whether we need to save image from camera preview or make a snapshot while snapping barcode
  /// image uri will be returned in [BarcodeScanningResult.snappedImage] property
  BarcodeImageGenerationType barcodeImageGenerationType;

  BarcodeScannerConfiguration(
      {this.topBarBackgroundColor,
      this.topBarButtonsColor,
      this.cameraOverlayColor,
      this.finderLineColor,
      this.finderTextHintColor,
      this.cancelButtonTitle,
      this.enableCameraButtonTitle,
      this.enableCameraExplanationText,
      this.finderTextHint,
      this.autoCancelTimeout,
      this.finderAspectRatio,
      this.finderLineWidth,
      this.successBeepEnabled,
      this.flashEnabled,
      this.orientationLockMode,
      List<BarcodeFormat>? barcodeFormats,
      this.cancelButtonHidden,
      BarcodeImageGenerationType? barcodeImageGenerationType})
      : barcodeFormats = barcodeFormats ?? [],
        barcodeImageGenerationType =
            barcodeImageGenerationType ?? BarcodeImageGenerationType.NONE;

  factory BarcodeScannerConfiguration.fromJson(Map<String, dynamic> json) =>
      _$BarcodeScannerConfigurationFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeScannerConfigurationToJson(this);
}

enum BarcodeImageGenerationType { NONE, VIDEO_FRAME, CAPTURED_IMAGE }

@JsonSerializable(includeIfNull: false, explicitToJson: true)
class DetectFromImageParams {
  ///file or content uri
  Uri uri;

  /// Enable more sensitive barcode detection.
  /// If set to true - will detect more barcodes.
  /// As a downside, might return false positives barcodes.
  /// Default is FALSE.
  bool enableHighSensitivityMode;

  /// Format of barcode which  need to recognize
  List<BarcodeFormat> barcodeFormats;

  DetectFromImageParams(
      this.uri, this.barcodeFormats, this.enableHighSensitivityMode);

  factory DetectFromImageParams.fromJson(Map<String, dynamic> json) =>
      _$DetectFromImageParamsFromJson(json);

  Map<String, dynamic> toJson() => _$DetectFromImageParamsToJson(this);
}

@JsonSerializable(includeIfNull: false, explicitToJson: true)
class FinderAspectRatio {
  /// Height of the finder window in pixels.
  int height;

  /// Width of the finder window in pixels.
  int width;

  FinderAspectRatio({required this.height, required this.width});

  factory FinderAspectRatio.fromJson(Map<String, dynamic> json) =>
      _$FinderAspectRatioFromJson(json);

  Map<String, dynamic> toJson() => _$FinderAspectRatioToJson(this);
}

typedef BarcodeDataFormatter = Future<BarcodeFormattedData> Function(
    BarcodeItem barcodeItem);

@JsonSerializable(includeIfNull: false, explicitToJson: true)
class BatchBarcodeScannerConfiguration {
  /// Allows to change data representation for scanned list items
  @JsonKey(ignore: true)
  BarcodeDataFormatter? barcodeFormatter;

  /// Background color of the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarBackgroundColor;

  /// Color of the titles of all buttons in the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsColor;

  /// Color buttons inactive color
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsInactiveColor;

  /// Color of barcodes count text
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? barcodesCountTextColor;

  /// Color of barcodes details action
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? detailsActionColor;

  /// Color of barcodes details background
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? detailsBackgroundColor;

  /// Color of barcodes details background
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? detailsPrimaryColor;

  /// Background color outside of the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? cameraOverlayColor;

  /// Color of the finder window's outline.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? finderLineColor;

  /// Color of the text hint under the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? finderTextHintColor;

  bool? cancelButtonHidden;

  /// Title of the cancel button.
  String? cancelButtonTitle;

  /// Title of the button that opens the screen where the user can allow
  /// the usage of the camera by the app.
  String? enableCameraButtonTitle;

  /// Text that will be displayed when the app
  /// is not allowed to use the camera, prompting the user
  /// to enable the usage of the camera.
  String? enableCameraExplanationText;

  /// Text hint shown under the finder window.
  String? finderTextHint;

  /// Text of submit button.
  String? submitButtonTitle;

  /// Text of clear button.
  String? clearButtonTitle;

  /// Text of count text.
  String? barcodesCountText;

  /// Text of fetch state text.
  String? fetchingStateText;

  /// Text when there no scanned barcodes yet.
  String? noBarcodesTitle;

  /// Aspect ratio of finder view.
  FinderAspectRatio? finderAspectRatio;

  /// Thickness of the finder window's outline.
  int? finderLineWidth;

  /// Controls whether to play a beep sound after a successful detection.
  /// Default value is TRUE.
  bool? successBeepEnabled;

  /// Controls whether the flash should be initially enabled.
  /// The default value is FALSE.
  bool? flashEnabled;

  /// Orientation lock mode of the camera: PORTRAIT or LANDSCAPE.
  /// By default the camera orientation is not locked.

  CameraOrientationMode? orientationLockMode;

  /// Format of barcode which  need to recognize
  List<BarcodeFormat> barcodeFormats;

  BatchBarcodeScannerConfiguration(
      {this.topBarBackgroundColor,
      this.topBarButtonsColor,
      this.topBarButtonsInactiveColor,
      this.barcodeFormatter,
      this.barcodesCountTextColor,
      this.detailsActionColor,
      this.detailsBackgroundColor,
      this.detailsPrimaryColor,
      this.cameraOverlayColor,
      this.finderLineColor,
      this.finderTextHintColor,
      this.cancelButtonHidden,
      this.cancelButtonTitle,
      this.enableCameraButtonTitle,
      this.enableCameraExplanationText,
      this.finderTextHint,
      this.submitButtonTitle,
      this.clearButtonTitle,
      this.barcodesCountText,
      this.fetchingStateText,
      this.noBarcodesTitle,
      this.finderAspectRatio,
      this.finderLineWidth,
      this.successBeepEnabled,
      this.flashEnabled,
      this.orientationLockMode,
      List<BarcodeFormat>? barcodeFormats})
      : barcodeFormats = barcodeFormats ?? const [];

  factory BatchBarcodeScannerConfiguration.fromJson(
          Map<String, dynamic> json) =>
      _$BatchBarcodeScannerConfigurationFromJson(json);

  Map<String, dynamic> toJson() =>
      _$BatchBarcodeScannerConfigurationToJson(this);
}

==> barcode_scanner-3.0.2.tar.gz: lib/barcode_scanning_data.dart <==
import 'dart:typed_data';

import 'package:barcode_scanner/common_data.dart';
import 'package:barcode_scanner/sdk_utils.dart';
import 'package:flutter/cupertino.dart';
import 'package:json_annotation/json_annotation.dart';

import 'barcode_parsers/barcode_scanner.dart';
import 'common_data.dart';

part 'barcode_scanning_data.g.dart';

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class BarcodeScanningResult extends Result {
  List<BarcodeItem> barcodeItems = <BarcodeItem>[];

  Uri? barcodeImageURI;

  BarcodeScanningResult(this.barcodeItems);

  BarcodeScanningResult.error(String message) {
    operationResult = OperationResult.ERROR;
    this.message = message;
  }

  BarcodeScanningResult.canceled() {
    operationResult = OperationResult.CANCELED;
  }

  factory BarcodeScanningResult.fromJson(Map<String, dynamic> json) =>
      _$BarcodeScanningResultFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeScanningResultToJson(this);
}

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class BarcodeItem {
  BarcodeFormattedResult? formattedResult;

  ///Scanned barcode format
  BarcodeFormat? barcodeFormat;

  ///Scanned accepted document formats
  AcceptedDocumentFormats? acceptedDocumentFormats;

  ///Result data from barcode
  String? text;

  @JsonKey(fromJson: uintListFromString)

  ///raw data of barcode
  Uint8List? rawBytes;

  BarcodeItem(this.barcodeFormat, this.text);

  factory BarcodeItem.fromJson(Map<String, dynamic> json) =>
      _$BarcodeItemFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeItemToJson(this);
}

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class BarcodeFormattedData {
  String? title;
  String? subtitle;

  BarcodeFormattedData({this.title, this.subtitle});

  factory BarcodeFormattedData.fromJson(Map<String, dynamic> json) =>
      _$BarcodeFormattedDataFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeFormattedDataToJson(this);
}

///Available barcode formats
enum BarcodeFormat {
  AZTEC,
  CODABAR,
  CODE_39,
  CODE_93,
  CODE_128,
  DATA_MATRIX,
  EAN_8,
  EAN_13,
  ITF,
  PDF_417,
  QR_CODE,
  RSS_14,
  RSS_EXPANDED,
  UPC_A,
  UPC_E,
  MSI_PLESSEY,
  UNKNOWN
}

///Available accepted document formats
enum AcceptedDocumentFormats {
  AAMVA,
  BOARDING_PASS,
  DE_MEDICAL_PLAN,
  DISABILITY_CERTIFICATE,
  ID_CARD_PDF_417,
  SEPA,
  SWISS_QR,
  VCARD
}

/// Available MSI Plessey Checksum Algorithm formats
enum MSIPlesseyChecksumAlgorithm {
  None,
  Mod10,
  Mod11IBM,
  Mod11NCR,
  Mod1010,
  Mod1110IBM,
  Mod1110NCR
}

///Available engine modes for barcode V3 scanner version
enum EngineMode { Legacy, NextGen }

class PredefinedBarcodes {
  ///return list of one dimensional barcode formats
  static List<BarcodeFormat> commonBarcodes() {
    return [
      BarcodeFormat.AZTEC,
      BarcodeFormat.CODABAR,
      BarcodeFormat.CODE_39,
      BarcodeFormat.CODE_93,
      BarcodeFormat.CODE_128,
      BarcodeFormat.DATA_MATRIX,
      BarcodeFormat.EAN_8,
      BarcodeFormat.EAN_13,
      BarcodeFormat.ITF,
      BarcodeFormat.PDF_417,
      BarcodeFormat.QR_CODE,
      BarcodeFormat.RSS_14,
      BarcodeFormat.RSS_EXPANDED,
      BarcodeFormat.UPC_A,
      BarcodeFormat.UPC_E,
    ];
  }

  static List<AcceptedDocumentFormats> acceptedDocumentFormats() {
    return [
      AcceptedDocumentFormats.AAMVA,
      AcceptedDocumentFormats.BOARDING_PASS,
      AcceptedDocumentFormats.DE_MEDICAL_PLAN,
      AcceptedDocumentFormats.DISABILITY_CERTIFICATE,
      AcceptedDocumentFormats.ID_CARD_PDF_417,
      AcceptedDocumentFormats.SEPA,
      AcceptedDocumentFormats.SWISS_QR,
      AcceptedDocumentFormats.VCARD
    ];
  }

  ///return list of one dimensional barcode formats
  static List<BarcodeFormat> oneDimensionalBarcodes() {
    return [
      BarcodeFormat.CODABAR,
      BarcodeFormat.CODE_128,
      BarcodeFormat.CODE_39,
      BarcodeFormat.CODE_93,
      BarcodeFormat.EAN_13,
      BarcodeFormat.EAN_8,
      BarcodeFormat.ITF,
      BarcodeFormat.UPC_A,
      BarcodeFormat.RSS_14,
      BarcodeFormat.RSS_EXPANDED,
      BarcodeFormat.UPC_E
    ];
  }

  ///return list of two dimensional barcode formats
  static List<BarcodeFormat> twoDimensionalBarcodes() {
    return [
      BarcodeFormat.AZTEC,
      BarcodeFormat.DATA_MATRIX,
      BarcodeFormat.PDF_417,
      BarcodeFormat.QR_CODE
    ];
  }
}

@JsonSerializable(includeIfNull: false, explicitToJson: true)
class BarcodeScannerConfiguration {
  /// Background color of the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarBackgroundColor;

  /// The color of the titles of all buttons in the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsColor;

  /// Background color outside the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? cameraOverlayColor;

  /// The color of the finder window's outline.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? finderLineColor;

  /// The color of the text hint under the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? finderTextHintColor;

  /// The color of the titles of all inactive buttons in the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsInactiveColor;

  /// To hide cancel button or not.
  bool? cancelButtonHidden;

  /// Title of the cancel button.
  String? cancelButtonTitle;

  /// Title of the button that opens the screen where the user can allow
  /// the usage of the camera by the app.
  String? enableCameraButtonTitle;

  /// Text that will be displayed when the app
  /// is not allowed to use the camera, prompting the user
  /// to enable the usage of the camera.
  String? enableCameraExplanationText;

  /// Text hint shown under the finder window.
  String? finderTextHint;

  /// cancel scanning and close view on timeout.
  int? autoCancelTimeout;

  /// Aspect ratio of finder view.
  FinderAspectRatio? finderAspectRatio;

  /// Thickness of the finder window's outline.
  int? finderLineWidth;

  /// Controls whether to play a beep sound after a successful detection.
  /// Default value is TRUE.
  bool? successBeepEnabled;

  /// Controls whether the flash should be initially enabled.
  /// The default value is FALSE.
  bool? flashEnabled;

  /// Orientation lock mode of the camera: PORTRAIT or LANDSCAPE.
  /// By default the camera orientation is not locked.

  CameraOrientationMode? orientationLockMode;

  /// Barcode formats which need to be recognized.
  List<BarcodeFormat>? barcodeFormats;

  /// Barcode formats which need to be recognized.
  List<AcceptedDocumentFormats>? acceptedDocumentFormats;

  /// Additional parameters for tweaking the detection of barcodes.
  BarcodeAdditionalParameters? additionalParameters;

  /// Param that handle whether we need to save image from camera preview or make a snapshot while snapping barcode
  /// image uri will be returned in [BarcodeScanningResult.snappedImage] property
  BarcodeImageGenerationType barcodeImageGenerationType =
      BarcodeImageGenerationType.NONE;

  /// Type of engine to be used in barcode scanner
  EngineMode engineMode;

  ///Set current zoom by a linear zoom value ranging from 0f to 1.0f. Optical Zoom Level 0f represents the minimum zoom while Optical Zoom Level 1.0f represents the maximum zoom.
  ///Default value is 0f.
  double? cameraZoomFactor;

  BarcodeScannerConfiguration(
      {this.topBarBackgroundColor,
      this.topBarButtonsColor,
      this.topBarButtonsInactiveColor,
      this.cameraOverlayColor,
      this.finderLineColor,
      this.finderTextHintColor,
      this.cancelButtonTitle,
      this.enableCameraButtonTitle,
      this.enableCameraExplanationText,
      this.finderTextHint,
      this.autoCancelTimeout,
      this.finderAspectRatio,
      this.finderLineWidth,
      this.successBeepEnabled,
      this.flashEnabled,
      this.orientationLockMode,
      this.barcodeFormats,
      this.acceptedDocumentFormats,
      this.cancelButtonHidden,
      this.barcodeImageGenerationType = BarcodeImageGenerationType.NONE,
      this.additionalParameters,
      this.engineMode = EngineMode.NextGen,
      this.cameraZoomFactor});

  factory BarcodeScannerConfiguration.fromJson(Map<String, dynamic> json) =>
      _$BarcodeScannerConfigurationFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeScannerConfigurationToJson(this);
}

enum BarcodeImageGenerationType { NONE, VIDEO_FRAME, CAPTURED_IMAGE }

@JsonSerializable(includeIfNull: false, explicitToJson: true)
class DetectFromImageParams {
  ///file or content uri
  Uri? uri;

  /// Barcode formats which need to be recognized.
  List<BarcodeFormat> barcodeFormats = <BarcodeFormat>[];

  /// Accepted Document formats which need to be recognized.
  List<AcceptedDocumentFormats> acceptedDocumentFormats =
      <AcceptedDocumentFormats>[];

  /// Additional parameters for tweaking the detection of barcodes.
  BarcodeAdditionalParameters additionalParameters;

  DetectFromImageParams(
    this.uri,
    this.barcodeFormats,
    this.acceptedDocumentFormats,
    this.additionalParameters,
  );

  factory DetectFromImageParams.fromJson(Map<String, dynamic> json) =>
      _$DetectFromImageParamsFromJson(json);

  Map<String, dynamic> toJson() => _$DetectFromImageParamsToJson(this);
}

@JsonSerializable(includeIfNull: false, explicitToJson: true)
class FinderAspectRatio {
  /// Height of the finder window in pixels.
  int height;

  /// Width of the finder window in pixels.
  int width;

  FinderAspectRatio({this.width = 0, this.height = 0});

  factory FinderAspectRatio.fromJson(Map<String, dynamic> json) =>
      _$FinderAspectRatioFromJson(json);

  Map<String, dynamic> toJson() => _$FinderAspectRatioToJson(this);
}

typedef BarcodeDataFormatter = Future<BarcodeFormattedData> Function(
    BarcodeItem barcodeItem);

@JsonSerializable(includeIfNull: false, explicitToJson: true)
class BatchBarcodeScannerConfiguration {
  /// Change data representation for scanned list items

  @JsonKey(ignore: true)
  BarcodeDataFormatter? barcodeFormatter;

  /// The background color of the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarBackgroundColor;

  /// The color of the titles of all buttons in the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsColor;

  /// The color of the titles of all inactive buttons in the top toolbar.

  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsInactiveColor;

  /// The color of barcodes count text
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? barcodesCountTextColor;

  /// The color of barcodes details action
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? detailsActionColor;

  /// The color of barcodes details background
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? detailsBackgroundColor;

  /// The color of barcodes details background
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? detailsPrimaryColor;

  /// The background color outside the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? cameraOverlayColor;

  /// The color of the finder window's outline.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? finderLineColor;

  /// The color of the text hint under the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? finderTextHintColor;

  bool? cancelButtonHidden;

  /// Title of the cancel button.
  String? cancelButtonTitle;

  /// Title of the button that opens the screen where the user can allow
  /// the usage of the camera by the app.
  String? enableCameraButtonTitle;

  /// Text that will be displayed when the app
  /// is not allowed to use the camera, prompting the user
  /// to enable the usage of the camera.
  String? enableCameraExplanationText;

  /// Text hint shown under the finder window.
  String? finderTextHint;

  /// Text of submit button.
  String? submitButtonTitle;

  /// Text of clear button.
  String? clearButtonTitle;

  /// Text of count text.
  String? barcodesCountText;

  /// Text of fetch state text.
  String? fetchingStateText;

  /// Text when there are no scanned barcodes yet.
  String? noBarcodesTitle;

  /// Aspect ratio of finder view.
  FinderAspectRatio? finderAspectRatio;

  /// Thickness of the finder window's outline.
  int? finderLineWidth;

  /// Controls whether to play a beep sound after a successful detection.
  /// Default value is TRUE.
  bool? successBeepEnabled;

  /// Controls whether the flash should be initially enabled.
  /// The default value is FALSE.
  bool? flashEnabled;

  /// Additional parameters for tweaking the detection of barcodes.
  BarcodeAdditionalParameters? additionalParameters;

  /// Orientation lock mode of the camera: PORTRAIT or LANDSCAPE.
  /// By default the camera orientation is not locked.

  CameraOrientationMode? orientationLockMode;

  /// Barcode formats which need to be recognized.
  List<BarcodeFormat>? barcodeFormats;

  /// Accepted document formats which need to be recognized.
  List<AcceptedDocumentFormats>? acceptedDocumentFormats;

  /// Type of engine to be used in barcode scanner
  EngineMode engineMode;

  ///Set current zoom by a linear zoom value ranging from 0f to 1.0f. Optical Zoom Level 0f represents the minimum zoom while Optical Zoom Level 1.0f represents the maximum zoom.
  ///Default value is 0f.
  // double? cameraZoomFactor;

  BatchBarcodeScannerConfiguration(
      {this.topBarBackgroundColor,
      this.topBarButtonsColor,
      this.topBarButtonsInactiveColor,
      this.barcodeFormatter,
      this.barcodesCountTextColor,
      this.detailsActionColor,
      this.detailsBackgroundColor,
      this.detailsPrimaryColor,
      this.cameraOverlayColor,
      this.finderLineColor,
      this.finderTextHintColor,
      this.cancelButtonHidden,
      this.cancelButtonTitle,
      this.enableCameraButtonTitle,
      this.enableCameraExplanationText,
      this.finderTextHint,
      this.submitButtonTitle,
      this.clearButtonTitle,
      this.barcodesCountText,
      this.fetchingStateText,
      this.noBarcodesTitle,
      this.finderAspectRatio,
      this.finderLineWidth,
      this.successBeepEnabled,
      this.flashEnabled,
      this.orientationLockMode,
      this.barcodeFormats,
      this.acceptedDocumentFormats,
      this.additionalParameters,
      this.engineMode = EngineMode.NextGen});

  // this.cameraZoomFactor});

  factory BatchBarcodeScannerConfiguration.fromJson(
          Map<String, dynamic> json) =>
      _$BatchBarcodeScannerConfigurationFromJson(json);

  Map<String, dynamic> toJson() =>
      _$BatchBarcodeScannerConfigurationToJson(this);
}

/// A class that contains additional parameters for barcodes detection and filtering.
@JsonSerializable(includeIfNull: false, explicitToJson: true)
class BarcodeAdditionalParameters {
  /// With this option, the scanner assumes that the barcode can be a GS1 barcode, and modifies the behavior as needed.
  /// You can set it to FALSE, if you don't want to see decoded FNC1 characters ("]C1" and ASCII char 29).
  /// The default is TRUE.
  bool? gs1DecodingEnabled;

  /// Minimum required text length of the detected barcode.
  /// The default is 0.
  /// NOTE: Currently works for ITF barcodes only!
  int? minimumTextLength;

  /// Maximum text length of the detected barcode. Setting to zero removes the limit.
  /// The default is 0.
  /// NOTE: Currently works for ITF barcodes only!
  int? maximumTextLength;

  /// Minimum required quiet zone on the barcode. Measured in modules (the size of minimal bar on the barcode).
  /// The default is 10.
  /// NOTE: Currently works for ITF barcodes only!
  int? minimum1DBarcodesQuietZone;

  /// when set to true, check digits for UPC, EAN and MSI Plessey codes are removed from result.
  /// Has no effect if both single and double digit MSI Plessey checksums are enabled. The default is false
  bool? stripCheckDigits;

  /// The checksum algorithms for MSI Plessey barcodes.
  ///  The default value is MSIPlesseyChecksumAlgorithm.Mod10.
  MSIPlesseyChecksumAlgorithm? msiPlesseyChecksumAlgorithm;

  BarcodeAdditionalParameters(
      {this.gs1DecodingEnabled,
      this.minimumTextLength,
      this.maximumTextLength,
      this.minimum1DBarcodesQuietZone,
      this.stripCheckDigits,
      this.msiPlesseyChecksumAlgorithm});

  factory BarcodeAdditionalParameters.fromJson(Map<String, dynamic> json) =>
      _$BarcodeAdditionalParametersFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeAdditionalParametersToJson(this);
}
